﻿using System;
using System.Drawing;
using System.IO;
using System.Text;
using System.Windows.Forms;

namespace Texto2Html
{
    public partial class frmmain : Form
    {
        enum ETipoDeSaida
        {
            iParagrafo = 0,
            iQuebraLinha = 1
        };

        ETipoDeSaida FormatoDeSaida = ETipoDeSaida.iParagrafo;

        public frmmain()
        {
            InitializeComponent();
        }

        private string TextoParaHTML(string textoOrigem)
        {
            StringBuilder sb = new StringBuilder();
            StringBuilder sbSaida = new StringBuilder();

            string textoFonte = textoOrigem;
            string[] linhas;
            string Linha = "";
            int x = 0;

            //verifica se a fonte termina com \n
            if (textoOrigem[textoOrigem.Length - 1] != '\n')
            {
                textoFonte = textoOrigem + '\n';
            }

            //pega as linha do texto origem
            linhas = textoFonte.Split('\n');
            while (x < linhas.Length)
            {
                //Pega uma linha
                Linha = linhas[x].Trim();
               
                if (Linha.Length == 0)
                {
                    if (sb.ToString().Trim().Length > 0)
                    {
                        //Apenda uma linha na saida
                        sbSaida.Append("<p>" + sb.ToString().Trim() + "</p>");
                        //Apenda uma linha em branco
                        sbSaida.AppendLine().AppendLine();
                    }

                    //limpa o buffer
                    sb.Clear();
                }
                //Mantem a anexação de linha para o string buffer.
                sb.Append(linhas[x]);

                //incrementa contador
                x++;
            }

            //Limpa
            sb.Clear();
            Array.Clear(linhas, 0, linhas.Length);
            //Retorna a string.
            return sbSaida.ToString().Trim();
        }

        private string TextoParaHTML(string textoOrigem, string tipoQuebraLinha)
        {
            StringBuilder sbSaida = new StringBuilder();

            string textoFonte = textoOrigem;
            string[] linhas;
            string Linha = "";
            int x = 0;

            //Pega as linhas do texto origem
            linhas = textoFonte.Split('\n');
            while (x < linhas.Length)
            {
                //Pega uma linha
                Linha = linhas[x].Trim();
                sbSaida.AppendLine(Linha + tipoQuebraLinha);
                x++;
            }

            //Limpa
            Array.Clear(linhas, 0, linhas.Length);
            //Retorna string.
            return sbSaida.ToString().Trim();
        }

        private void btnConverter_Click(object sender, EventArgs e)
        {
            string textoFonte = txtTextoOrigem.Text.Trim();

            if (textoFonte.Length > 0)
            {
                if (chkEncodeCaracteresEspeciais.Checked)
                {
                    //Substitui caracteres especiais
                    textoFonte = textoFonte.Replace("&", "&amp;");
                    textoFonte = textoFonte.Replace(">", "&gt");
                    textoFonte = textoFonte.Replace("<", "&lt");
                    textoFonte = textoFonte.Replace("©", "&copy;");
                    textoFonte = textoFonte.Replace("®", "&reg;");
                    textoFonte = textoFonte.Replace("€", "&euro;");
                    textoFonte = textoFonte.Replace("™", "&trade;");
                    textoFonte = textoFonte.Replace("\"", "&quot;");
                }

                if (FormatoDeSaida == ETipoDeSaida.iParagrafo)
                {
                    txtHTML.Text = TextoParaHTML(textoFonte);
                }
                if (FormatoDeSaida == ETipoDeSaida.iQuebraLinha)
                {
                    txtHTML.Text = TextoParaHTML(textoFonte,cboQuebraLinha.Text);
                }
            }
        }

        private void btnFechar_Click(object sender, EventArgs e)
        {
            txtHTML.Clear();
            txtTextoOrigem.Clear();
            Close();
        }

        private void btnColar_Click(object sender, EventArgs e)
        {
            txtTextoOrigem.Paste();
            txtTextoOrigem.Focus();
        }

        private void btnCopiar_Click(object sender, EventArgs e)
        {
            txtHTML.SelectAll();
            txtHTML.Copy();
            txtHTML.Focus();
        }

        private void btnAjuda_Click(object sender, EventArgs e)
        {
            MessageBox.Show("Conversor de Texto para HTML - 1.0", "Sobre", 
                MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        private void frmmain_Load(object sender, EventArgs e)
        {
            FormatoDeSaida = ETipoDeSaida.iParagrafo;
            cboQuebraLinha.SelectedIndex = 0;
        }

        private void rdbTagParagrafo_CheckedChanged(object sender, EventArgs e)
        {
            FormatoDeSaida = ETipoDeSaida.iParagrafo;
            cboQuebraLinha.Enabled = false;
            rdbTagParagrafo.ForeColor = Color.LightSalmon;
            rdbTagQuebraLinha.ForeColor = Color.White;
        }

        private void rdbTagQuebraLinha_CheckedChanged(object sender, EventArgs e)
        {
            FormatoDeSaida = ETipoDeSaida.iQuebraLinha;
            cboQuebraLinha.Enabled = true;
            rdbTagParagrafo.ForeColor = Color.White;
            rdbTagQuebraLinha.ForeColor = Color.LightSalmon;
        }

        private void chkEncodeCaracteresEspeciais_CheckedChanged(object sender, EventArgs e)
        {
            if (chkEncodeCaracteresEspeciais.Checked)
            {
                chkEncodeCaracteresEspeciais.ForeColor = Color.LightSalmon;
            }
            else
            {
                chkEncodeCaracteresEspeciais.ForeColor = Color.White;
            }
        }

        private void btnResetar_Click(object sender, EventArgs e)
        {
            txtHTML.Clear();
            txtTextoOrigem.Clear();
            txtTextoOrigem.Focus();
        }

        private void btnCarregar_Click(object sender, EventArgs e)
        {
            OpenFileDialog od = new OpenFileDialog();

            od.Title = "Abrir";
            od.Filter = "Text Files(*.txt)|*.txt|All Files(*.*)|*.*";
            if (od.ShowDialog() == DialogResult.OK)
            {
                //carrega arquivo texto 
                try
                {
                    using (StreamReader sr = new StreamReader(od.FileName))
                    {
                        txtTextoOrigem.Text = sr.ReadToEnd();
                        sr.Close();
                    }
                    txtTextoOrigem.Focus();
                }
                catch (Exception err)
                {
                    MessageBox.Show(err.Message, "Aviso",
                        MessageBoxButtons.OK, MessageBoxIcon.Warning);
                }
            }
            od.Dispose();
        }

        private void btnSalvar_Click(object sender, EventArgs e)
        {
            SaveFileDialog sd = new SaveFileDialog();

            sd.Title = "Salvar";
            sd.Filter = "Text Files(*.txt)|*.txt|HTML Files(*.html)|*.html";
            sd.DefaultExt = "txt";

            if (sd.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    using (StreamWriter sw = new StreamWriter(sd.FileName))
                    {
                        //escreve para o arquivo de saida
                        sw.Write(txtHTML.Text);
                        sw.Close();
                    }
                }
                catch (Exception err)
                {
                    MessageBox.Show(err.Message, "Aviso",
                        MessageBoxButtons.OK, MessageBoxIcon.Warning);
                }
            }
            sd.Dispose();
        }
    }
}
